//@line 42 "/builds/tinderbox/Tb-Trunk/Linux_2.6.18-8.el5_Depend/mozilla/mail/base/content/contentAreaClick.js"

/*
 * - [ Dependencies ] ---------------------------------------------------------
 *  utilityOverlay.js:
 *    - gatherTextUnder
 */

  var pref = Components.classes["@mozilla.org/preferences-service;1"].getService(Components.interfaces.nsIPrefBranch);
  
  /** 
   * extract the href from the link click event. 
   * We look for HTMLAnchorElement, HTMLAreaElement, HTMLLinkElement,
   * HTMLInputElement.form.action, and nested anchor tags.
   * 
   * @return href for the url being clicked
   */
  function hRefForClickEvent(event)
  {
    var target = event.target;
    var href;
    var isKeyPress = (event.type == "keypress");

    if (target instanceof HTMLAnchorElement ||
        target instanceof HTMLAreaElement   ||
        target instanceof HTMLLinkElement)
    {
      if (target.hasAttribute("href")) 
        href = target.href;
    }
    else if (target instanceof HTMLInputElement)
    {
      if (target.form && target.form.action)
        href = target.form.action;      
    }
    else 
    {
      // we may be nested inside of a link node
      var linkNode = event.originalTarget;
      while (linkNode && !(linkNode instanceof HTMLAnchorElement))
        linkNode = linkNode.parentNode;
      
      if (linkNode)
        href = linkNode.href;
    }

    return href;
  }

  function messagePaneOnResize(event)
  {
    // scale any overflowing images
    var messagepane = document.getElementById("messagepane");
    var doc = messagepane.contentDocument;
    var imgs = doc.images;
    for each (var img in imgs)
    {
      if (img.className == "moz-attached-image")
      {
        if (img.naturalWidth <= doc.width)
        {
          img.removeAttribute("isshrunk");
          img.removeAttribute("overflowing");
        }
        else if (img.hasAttribute("shrinktofit")) 
        {
          img.setAttribute("isshrunk", "true");
          img.removeAttribute("overflowing");
        }
        else
        {
          img.setAttribute("overflowing", "true");
          img.removeAttribute("isshrunk");
        }
      }
    }
  }

  // Called whenever the user clicks in the content area,
  // except when left-clicking on links (special case)
  // should always return true for click to go through
  function contentAreaClick(event) 
  {
    var href = hRefForClickEvent(event);
    if (href) 
    {
      handleLinkClick(event, href, null);
      if (!event.button)  // left click only
        return gPhishingDetector.warnOnSuspiciousLinkClick(href); // let the phishing detector check the link
    }
    else if (!event.button)
    {
      var target = event.target;
      // is this an image that we might want to scale?
      const Ci = Components.interfaces;
      if (target instanceof Ci.nsIImageLoadingContent) 
      {
        // make sure it loaded successfully
        var req = target.getRequest(Ci.nsIImageLoadingContent.CURRENT_REQUEST);
        if (!req || req.imageStatus & Ci.imgIRequest.STATUS_ERROR)
          return true;
        // is it an inline attachment?
        if (/^moz-attached-image/.test(target.className))
        {
          if (target.hasAttribute("isshrunk"))
          {
            // currently shrunk to fit, so unshrink it
            target.removeAttribute("isshrunk");
            target.removeAttribute("shrinktofit");
            target.setAttribute("overflowing", "true");
          }
          else if (target.hasAttribute("overflowing"))
          {
            // user wants to shrink now
            target.setAttribute("isshrunk", "true");
            target.setAttribute("shrinktofit", "true");
            target.removeAttribute("overflowing");
          }
        }
      }
    }
    
    return true;
  }

  function openNewTabOrWindow(event, href, sendReferrer)
  {
    // always return false for stand alone mail (MOZ_THUNDERBIRD)
    // let someone else deal with it
    return false;
  }

  function getContentFrameURI(aFocusedWindow)
  {
    var contentFrame = isContentFrame(aFocusedWindow) ? aFocusedWindow : window.content;
    return contentFrame.location.href;
  }

  function handleLinkClick(event, href, linkNode)
  {
    // Make sure we are allowed to open this URL
    var focusedWindow = document.commandDispatcher.focusedWindow;
    var sourceURL = getContentFrameURI(focusedWindow);
    urlSecurityCheck(href, sourceURL);
    return false;
  }

  function middleMousePaste( event )
  {
    return false;
  }

  function makeURLAbsolute( base, url ) 
  {
    // Construct nsIURL.
    var ioService = Components.classes["@mozilla.org/network/io-service;1"]
                  .getService(Components.interfaces.nsIIOService);
    var baseURI  = ioService.newURI(base, null, null);

    return ioService.newURI(baseURI.resolve(url), null, null).spec;
  }
